@@ -533,6 +533,102 @@ scan_convert_helper_float16 (
     }
 }
 
+static void
+scan_convert_helper_bfp (
+                         Channel * mask,
+                         GSList ** scanlines,
+                         int width,
+                         int height,
+                         int antialias
+                         )
+{
+  PixelArea maskPR;
+  PixelRow bufRow;
+  GSList * list;
+  guint16 * buf = NULL;
+  guint16 * b = NULL;
+  int * vals = NULL;
+  int val;
+  int start, end;
+  int x, x2, w;
+  int i, j;
+
+  
+  pixelarea_init (&maskPR, drawable_data (GIMP_DRAWABLE(mask)),
+                  0, 0, 
+                  0, 0,
+                  TRUE);
+
+  if (antialias)
+    {
+      buf = (guint16 *) g_malloc (width / SUPERSAMPLE * sizeof (guint16));
+      vals = (int *) g_malloc (sizeof (int) * width);
+      pixelrow_init (&bufRow, drawable_tag (GIMP_DRAWABLE (mask)),
+                     (guchar*) buf, width/SUPERSAMPLE);
+    }
+
+  for (i = 0; i < height; i++)
+    {
+      list = scanlines[i];
+
+      /*  zero the vals array  */
+      if (antialias && !(i % SUPERSAMPLE))
+	memset (vals, 0, width * sizeof (int));
+
+      while (list)
+	{
+	  x = (long) list->data;
+	  list = g_slist_next(list);
+	  if (!list)
+	      g_message ("Cannot properly scanline convert polygon!\n");
+	  else
+	    {
+	      /*  bounds checking  */
+	      x = BOUNDS (x, 0, width);
+	      x2 = BOUNDS ((long) list->data, 0, width);
+
+	      w = x2 - x;
+
+	      if (w > 0)
+		{
+		  if (! antialias)
+		    channel_add_segment (mask, x, i, w, 1.0);
+		  else
+		    for (j = 0; j < w; j++)
+		      vals[j + x] += 65535;
+		}
+
+	      list = g_slist_next (list);
+	    }
+	}
+
+      if (antialias && !((i+1) % SUPERSAMPLE))
+	{
+	  b = buf;
+	  start = 0;
+	  end = width;
+	  for (j = start; j < end; j += SUPERSAMPLE)
+	    {
+	      val = 0;
+	      for (x = 0; x < SUPERSAMPLE; x++)
+		val += vals[j + x];
+
+	      *b++ = (guint16) (val / SUPERSAMPLE2);
+	    }
+
+	  pixelarea_write_row (&maskPR, &bufRow, 0, (i / SUPERSAMPLE), (width / SUPERSAMPLE));
+	}
+
+      g_slist_free (scanlines[i]);
+    }
+
+  if (antialias)
+    {
+      g_free (vals);
+      g_free (buf);
+    }
+}
+
 static void
 scan_convert_helper (
                      Channel * mask,
@@ -556,6 +652,9 @@ scan_convert_helper (
     case PRECISION_FLOAT16:
       scan_convert_helper_float16 (mask, scanlines, width, height, antialias);
       break;
+    case PRECISION_BFP:
+      scan_convert_helper_bfp (mask, scanlines, width, height, antialias);
+      break;
     case PRECISION_NONE:
       g_warning ("scan_convert_helper bad precision");
       break;
@@ -667,7 +766,7 @@ free_select_button_press (Tool *tool, GdkEventButton *bevent,
 
   gdk_pointer_grab (gdisp->canvas->window, FALSE,
 		    GDK_POINTER_MOTION_HINT_MASK | GDK_BUTTON1_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
-		    NULL, NULL, bevent->time);
+		    NULL, NULL, bevent->time);		   
 
   tool->state = ACTIVE;
   tool->gdisp_ptr = gdisp_ptr;
