@@ -266,7 +266,7 @@ blend_row_u8  (
   guint8 *dest         = (guint8*)pixelrow_data (dest_row);
   guint8 *src1         = (guint8*)pixelrow_data (src1_row);
   guint8 *src2         = (guint8*)pixelrow_data (src2_row);
-  gint    width        = pixelrow_width (dest_row);
+  gint    width        = MIN(pixelrow_width (dest_row),pixelrow_width (src1_row));
   Tag     tag          = tag_alpha (src1_tag);
   Tag     tag2         = tag_alpha (src2_tag);
   Tag     tag3         = tag_alpha (dest_tag);
@@ -377,7 +377,7 @@ darken_row_u8 (
   guint8 *dest          = (guint8*)pixelrow_data (dest_row);
   guint8 *src1          = (guint8*)pixelrow_data (src1_row);
   guint8 *src2          = (guint8*)pixelrow_data (src2_row);
-  gint    width         = pixelrow_width (dest_row);
+  gint    width         = MIN(pixelrow_width (dest_row),pixelrow_width (src1_row));
   gint    num_channels1 = tag_num_channels (src1_tag);
   gint    num_channels2 = tag_num_channels (src2_tag);
   
@@ -420,7 +420,7 @@ lighten_row_u8 (
   guint8 *dest          = (guint8*)pixelrow_data (dest_row);
   guint8 *src1          = (guint8*)pixelrow_data (src1_row);
   guint8 *src2          = (guint8*)pixelrow_data (src2_row);
-  gint    width         = pixelrow_width (dest_row);
+  gint    width         = MIN(pixelrow_width (dest_row),pixelrow_width (src1_row));
   gint    num_channels1 = tag_num_channels (src1_tag);
   gint    num_channels2 = tag_num_channels (src2_tag);
 
@@ -465,7 +465,7 @@ hsv_only_row_u8 (
   guint8 *dest          = (guint8*)pixelrow_data (dest_row);
   guint8 *src1          = (guint8*)pixelrow_data (src1_row);
   guint8 *src2          = (guint8*)pixelrow_data (src2_row);
-  gint    width         = pixelrow_width (dest_row);
+  gint    width         = MIN(pixelrow_width (dest_row),pixelrow_width (src1_row));
   gint    num_channels1 = tag_num_channels (src1_tag);
   gint    num_channels2 = tag_num_channels (src2_tag);
 
@@ -524,7 +524,7 @@ color_only_row_u8 (
   guint8 *dest          = (guint8*)pixelrow_data (dest_row);
   guint8 *src1          = (guint8*)pixelrow_data (src1_row);
   guint8 *src2          = (guint8*)pixelrow_data (src2_row);
-  gint    width         = pixelrow_width (dest_row);
+  gint    width         = MIN(pixelrow_width (dest_row),pixelrow_width (src1_row));
   gint    num_channels1 = tag_num_channels (src1_tag);
   gint    num_channels2 = tag_num_channels (src2_tag);
 
@@ -572,7 +572,7 @@ multiply_row_u8 (
   guint8 *dest          = (guint8*)pixelrow_data (dest_row);
   guint8 *src1          = (guint8*)pixelrow_data (src1_row);
   guint8 *src2          = (guint8*)pixelrow_data (src2_row);
-  gint    width         = pixelrow_width (dest_row);
+  gint    width         = MIN(pixelrow_width (dest_row),pixelrow_width (src1_row));
   gint    num_channels1 = tag_num_channels (src1_tag);
   gint    num_channels2 = tag_num_channels (src2_tag);
 
@@ -611,7 +611,7 @@ screen_row_u8 (
   guint8 *dest          = (guint8*)pixelrow_data (dest_row);
   guint8 *src1          = (guint8*)pixelrow_data (src1_row);
   guint8 *src2          = (guint8*)pixelrow_data (src2_row);
-  gint    width         = pixelrow_width (dest_row);
+  gint    width         = MIN(pixelrow_width (dest_row),pixelrow_width (src1_row));
   gint    num_channels1 = tag_num_channels (src1_tag);
   gint    num_channels2 = tag_num_channels (src2_tag);
   
@@ -651,7 +651,7 @@ overlay_row_u8 (
   guint8 *dest          = (guint8*)pixelrow_data (dest_row);
   guint8 *src1          = (guint8*)pixelrow_data (src1_row);
   guint8 *src2          = (guint8*)pixelrow_data (src2_row);
-  gint    width         = pixelrow_width (dest_row);
+  gint    width         = MIN(pixelrow_width (dest_row),pixelrow_width (src1_row));
   gint    num_channels1 = tag_num_channels (src1_tag);
   gint    num_channels2 = tag_num_channels (src2_tag);
 
@@ -694,7 +694,7 @@ add_row_u8 (
   guint8 *dest          = (guint8*)pixelrow_data (dest_row);
   guint8 *src1          = (guint8*)pixelrow_data (src1_row);
   guint8 *src2          = (guint8*)pixelrow_data (src2_row);
-  gint    width         = pixelrow_width (dest_row);
+  gint    width         = MIN(pixelrow_width (dest_row),pixelrow_width (src1_row));
   gint    num_channels1 = tag_num_channels (src1_tag);
   gint    num_channels2 = tag_num_channels (src2_tag);
   
@@ -736,7 +736,7 @@ subtract_row_u8 (
   guint8 *dest          = (guint8*)pixelrow_data (dest_row);
   guint8 *src1          = (guint8*)pixelrow_data (src1_row);
   guint8 *src2          = (guint8*)pixelrow_data (src2_row);
-  gint    width         = pixelrow_width (dest_row);
+  gint    width         = MIN(pixelrow_width (dest_row),pixelrow_width (src1_row));
   gint    num_channels1 = tag_num_channels (src1_tag);
   gint    num_channels2 = tag_num_channels (src2_tag);
 
@@ -778,7 +778,7 @@ difference_row_u8 (
   guint8 *dest          = (guint8*)pixelrow_data (dest_row);
   guint8 *src1          = (guint8*)pixelrow_data (src1_row);
   guint8 *src2          = (guint8*)pixelrow_data (src2_row);
-  gint    width         = pixelrow_width (dest_row);
+  gint    width         = MIN(pixelrow_width (dest_row),pixelrow_width (src1_row));
   gint    num_channels1 = tag_num_channels (src1_tag);
   gint    num_channels2 = tag_num_channels (src2_tag);
 
@@ -869,7 +869,7 @@ replace_row_u8  (
   guint8 *src1          = (guint8*)pixelrow_data (src1_row);
   guint8 *src2          = (guint8*)pixelrow_data (src2_row);
   guint8 *mask          = (guint8*)pixelrow_data (mask_row);
-  gint    width         = pixelrow_width (dest_row);
+  gint    width         = MIN(pixelrow_width (dest_row),pixelrow_width (src1_row));
   gint    num_channels1 = tag_num_channels (src1_tag);
   gint    num_channels2 = tag_num_channels (src2_tag);
 
