@@ -707,13 +707,37 @@ gdisplay_canvas_events (GtkWidget *canvas,
     else if (active_tool && !gimage_is_empty (gdisp->gimage) &&
         !(state & (GDK_BUTTON1_MASK | GDK_BUTTON2_MASK | GDK_BUTTON3_MASK)))
     {
+      int can_cursor = 0;  /* check whether we are not rejected later */
       GdkEventMotion me;
+      Layer *layer;
+      double x, y;
+ 
+ 
       me.x = tx;  me.y = ty;
       me.state = state;
+      gdisplay_untransform_coords_f (gdisp,
+                                me.x, me.y,
+                                &x, &y,
+                                FALSE);
+   
+      /* TODO move the checks below out of the active_tool->cursor_update_func's
+       */
+      if ((layer = gimage_get_active_layer (gdisp->gimage)))
+      {
+        int off_x, off_y;
+        drawable_offsets (GIMP_DRAWABLE(layer), &off_x, &off_y);
+        if (x >= off_x && y >= off_y &&
+            x < (off_x + drawable_width (GIMP_DRAWABLE(layer))) &&
+            y < (off_y + drawable_height (GIMP_DRAWABLE(layer))))
+          can_cursor = 1;
+      }
 #     ifndef DISP_DEBUG
-      if(active_tool->gdisp_ptr == gdisp)
+      /*if(active_tool->gdisp_ptr == gdisp)*/
 #     endif
+      if(can_cursor)
+      {
         (* active_tool->cursor_update_func) (active_tool, &me, gdisp);
+      }
     }
     else if (gdisp_busy == BUSY_DOWN)
     {
