@@ -950,8 +950,11 @@ gtk_wrap_box_expose (GtkWidget      *widget,
       if (GTK_WIDGET_DRAWABLE (child->widget) &&
 	  GTK_WIDGET_NO_WINDOW (child->widget) &&
 	  gtk_widget_intersect (child->widget, &event->area, &child_event.area))
+#if GTK_MAJOR_VERSION < 2
+	gtk_widget_event (child->widget, (GdkEvent*) &child_event);
+#else
         GTK_WIDGET_CLASS (parent_class)->expose_event (widget, event);
-	/*gtk_widget_event (child->widget, (GdkEvent*) &child_event);*/
+#endif
   
   return TRUE;
 }
