@@ -53,7 +53,6 @@
 #include "minimize.h"
 #define session_set_window_geometry(a,b,c)
 #define dialog_register(a)
-#define _(x) x
 #define dialog_unregister(a)
 #define session_get_window_info(a,b)
 
@@ -420,8 +419,10 @@ info_dialog_add_spinbutton (InfoDialog    *idialog,
 				   step_increment, page_increment, page_size);
   spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment),
 				    climb_rate, MAX (MIN (digits, 6), 0));
+#if GTK_MAJOR_VERSION < 2
   gtk_spin_button_set_shadow_type (GTK_SPIN_BUTTON (spinbutton),
 				   GTK_SHADOW_NONE);
+#endif
   gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton), TRUE);
   gtk_widget_set_usize (spinbutton, 75, 0);
 
