@@ -204,7 +204,9 @@ paintbrush_options_new (void)
   options->fade_out_w =  
     gtk_adjustment_new (options->fade_out_d,  1e-5, 32767.0, 1.0, 50.0, 0.0);
   spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (options->fade_out_w), 1.0, 0.0);
+#if GTK_MAJOR_VERSION < 2
   gtk_spin_button_set_shadow_type (GTK_SPIN_BUTTON (spinbutton), GTK_SHADOW_NONE);
+#endif
   gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton), TRUE);
   gtk_widget_set_usize (spinbutton, 75, 0);
   gtk_signal_connect (GTK_OBJECT (options->fade_out_w), "value_changed",
@@ -429,14 +431,22 @@ paintbrush_motion (PaintCore *paint_core,
   /* apply the next bit of remaining paint */
   if (paint_left > 0.001)
     {
+      gdouble pressure = 1.0;
+
+      if(pressure_options->opacity)
+        if(pressure_options->size)
+          pressure = paint_core->curpressure;
+        else
+          pressure = pow(paint_core->curpressure, 2);
+
       /* Set up the painthit canvas */
       paint_core_16_area_setup (paint_core, drawable);
       
       /* apply it to the image */
       paint_core_16_area_paste (paint_core, drawable,
-                                current_device ? (gfloat) paint_left * paint_core->curpressure : (gfloat) paint_left,
+                                current_device ? (gfloat) paint_left * pressure : (gfloat) paint_left,
                                 (gfloat) gimp_brush_get_opacity (),
-                                SOFT,
+                                pressure_options->pressure ? HARD : SOFT,
 				scale,
                                 incremental ? INCREMENTAL : CONSTANT,
                                 gimp_brush_get_paint_mode ());
